DynInbox

Struct DynInbox 

pub struct DynInbox<T> { /* private fields */ }
A dynamic inbox that can accept messages of any type, as long as they are part of the specified set.

An inbox is typed as: DynInbox<Set![Msg1, Msg2, ...]>.

Conversions between inboxes:

Implementations

Source

impl<T> DynInbox<T>

pub fn new_unchecked(inbox: Arc<dyn DynPolyBox>) -> DynInbox<T>

pub fn new<R>(inbox: R) -> DynInbox<T>
where R: DynPolyBox + PolyBox + 'static, T: SubsetOf<<R as PolyBox>::Set>,